@@ -40,15 +40,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "no opts",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 0,
 				},
 			},
 			state:   nil,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			want:    stateOut,
 			ok:      true,
 		},
@@ -56,15 +56,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "failed to run terraform import",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 1,
 				},
 			},
 			state:   nil,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			want:    nil,
 			ok:      false,
 		},
@@ -72,15 +72,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "with opts",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "-input=false", "-no-color", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ -input=false -no-color aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state-out=/path/to/out.tfstate", "-input=false", "-no-color", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state-out=.+ -input=false -no-color time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 0,
 				},
 			},
 			state:   nil,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			opts:    []string{"-input=false", "-no-color"},
 			want:    stateOut,
 			ok:      true,
@@ -89,15 +89,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "with state",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-no-color", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -no-color aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-no-color", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -no-color time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 0,
 				},
 			},
 			state:   state,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			opts:    []string{"-input=false", "-no-color"},
 			want:    stateOut,
 			ok:      true,
@@ -106,15 +106,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "with state and -state= (conflict error)",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-state=foo.tfstate", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -state=foo.tfstate aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-state=foo.tfstate", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -state=foo.tfstate time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 0,
 				},
 			},
 			state:   state,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			opts:    []string{"-input=false", "-state=foo.tfstate"},
 			want:    nil,
 			ok:      false,
@@ -123,15 +123,15 @@ func TestTerraformCLIImport(t *testing.T) {
 			desc: "with -state-out= (conflict error)",
 			mockCommands: []*mockCommand{
 				{
-					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-state-out=foo.tfstate", "aws_security_group.foo", "sg-12345678"},
-					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -state-out=foo.tfstate aws_security_group.foo sg-12345678$`),
+					args:     []string{"terraform", "import", "-state=/path/to/tempfile", "-state-out=/path/to/out.tfstate", "-input=false", "-state-out=foo.tfstate", "time_static.foo", "2006-01-02T15:04:05Z"},
+					argsRe:   regexp.MustCompile(`^terraform import -state=.+ -state-out=.+ -input=false -state-out=foo.tfstate time_static.foo 2006-01-02T15:04:05Z$`),
 					runFunc:  runFunc,
 					exitCode: 0,
 				},
 			},
 			state:   state,
-			address: "aws_security_group.foo",
-			id:      "sg-12345678",
+			address: "time_static.foo",
+			id:      "2006-01-02T15:04:05Z",
 			opts:    []string{"-input=false", "-state-out=foo.tfstate"},
 			want:    nil,
 			ok:      false,
@@ -160,9 +160,7 @@ func TestAccTerraformCLIImport(t *testing.T) {
 	SkipUnlessAcceptanceTestEnabled(t)
 
 	source := `
-resource "time_static" "foo" {
-  triggers = {}
-}
+resource "time_static" "foo" { triggers = {} }
 `
 	e := SetupTestAcc(t, source)
 	terraformCLI := NewTerraformCLI(e)
