@@ -2,10 +2,12 @@ package tfmigrate
 
 import (
 	"context"
+	"fmt"
 	"os"
 	"path/filepath"
 	"reflect"
 	"sort"
+	"strings"
 	"testing"
 
 	"github.com/minamijoyo/tfmigrate/tfexec"
@@ -953,3 +955,183 @@ resource "null_resource" "qux2" {}
 		t.Error("expect not to have changes in toDir")
 	}
 }
+
+func TestAccMultiStateMigratorPlanWithSwitchBackToRemoteFuncError(t *testing.T) {
+	tfexec.SkipUnlessAcceptanceTestEnabled(t)
+	ctx := context.Background()
+
+	// setup the initial files and states
+	fromBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/fromDir")
+	// Intentionally remove the bucket key from Terraform backend configuration,
+	// to force an error when switching back to remote state.
+	fromBackend = strings.ReplaceAll(fromBackend, fmt.Sprintf("bucket = \"%s\"", tfexec.TestS3Bucket), "")
+
+	fromSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+resource "null_resource" "baz" {}
+`
+	fromWorkspace := "default"
+	// Explicitly pass a -backend-config=bucket= option to terraform init, such
+	// that the initial init/apply works.
+	fromTf := tfexec.SetupTestAccWithApply(t, fromWorkspace, fromBackend+fromSource, fmt.Sprintf("-backend-config=bucket=%s", tfexec.TestS3Bucket))
+
+	toBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/toDir")
+	toSource := `
+resource "null_resource" "qux" {}
+`
+	toWorkspace := "default"
+	toTf := tfexec.SetupTestAccWithApply(t, toWorkspace, toBackend+toSource)
+
+	// update terraform resource files for migration
+	fromUpdatedSource := `
+resource "null_resource" "baz" {}
+`
+	tfexec.UpdateTestAccSource(t, fromTf, fromBackend+fromUpdatedSource)
+
+	toUpdatedSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar2" {}
+resource "null_resource" "qux" {}
+`
+	tfexec.UpdateTestAccSource(t, toTf, toBackend+toUpdatedSource)
+
+	// perform state migration
+	actions := []MultiStateAction{
+		NewMultiStateMvAction("null_resource.foo", "null_resource.foo"),
+		NewMultiStateMvAction("null_resource.bar", "null_resource.bar2"),
+	}
+	o := &MigratorOption{}
+	force := false
+	m := NewMultiStateMigrator(fromTf.Dir(), toTf.Dir(), fromWorkspace, toWorkspace, actions, o, force, false, false)
+
+	err := m.Plan(ctx)
+	if err == nil {
+		t.Fatalf("expected migrator plan error")
+	}
+
+	expected := "Error: \"bucket\": required field is not set"
+	if !strings.Contains(err.Error(), expected) {
+		t.Fatalf("expected migrator plan error to contain %s, got: %s", expected, err.Error())
+	}
+}
+
+func TestAccMultiStateMigratorPlanWithInvalidMigration(t *testing.T) {
+	tfexec.SkipUnlessAcceptanceTestEnabled(t)
+	ctx := context.Background()
+
+	// setup the initial files and states
+	fromBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/fromDir")
+
+	fromSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+resource "null_resource" "baz" {}
+`
+	fromWorkspace := "default"
+	fromTf := tfexec.SetupTestAccWithApply(t, fromWorkspace, fromBackend+fromSource)
+
+	toBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/toDir")
+	toSource := `
+resource "null_resource" "qux" {}
+`
+	toWorkspace := "default"
+	toTf := tfexec.SetupTestAccWithApply(t, toWorkspace, toBackend+toSource)
+
+	// update terraform resource files for migration
+	fromUpdatedSource := `
+resource "null_resource" "baz" {}
+`
+	tfexec.UpdateTestAccSource(t, fromTf, fromBackend+fromUpdatedSource)
+
+	toUpdatedSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar2" {}
+resource "null_resource" "qux" {}
+`
+	tfexec.UpdateTestAccSource(t, toTf, toBackend+toUpdatedSource)
+
+	// perform state migration
+	actions := []MultiStateAction{
+		NewMultiStateMvAction("null_resource.foo_bar", "null_resource.foo"),
+		NewMultiStateMvAction("null_resource.bar", "null_resource.bar2"),
+	}
+	o := &MigratorOption{}
+	force := false
+	m := NewMultiStateMigrator(fromTf.Dir(), toTf.Dir(), fromWorkspace, toWorkspace, actions, o, force, false, false)
+
+	err := m.Plan(ctx)
+	if err == nil {
+		t.Fatalf("expected migrator plan error")
+	}
+
+	expected := "Invalid source address"
+	if !strings.Contains(err.Error(), expected) {
+		t.Fatalf("expected migrator plan error to contain %s, got: %s", expected, err.Error())
+	}
+}
+
+func TestAccMultiStateMigratorPlanWithInvalidMigrationAndSwitchBackToRemoteFuncError(t *testing.T) {
+	tfexec.SkipUnlessAcceptanceTestEnabled(t)
+	ctx := context.Background()
+
+	// setup the initial files and states
+	fromBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/fromDir")
+	// Intentionally remove the bucket key from Terraform backend configuration,
+	// to force an error when switching back to remote state.
+	fromBackend = strings.ReplaceAll(fromBackend, fmt.Sprintf("bucket = \"%s\"", tfexec.TestS3Bucket), "")
+
+	fromSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar" {}
+resource "null_resource" "baz" {}
+`
+	fromWorkspace := "default"
+	// Explicitly pass a -backend-config=bucket= option to terraform init, such
+	// that the initial init/apply works.
+	fromTf := tfexec.SetupTestAccWithApply(t, fromWorkspace, fromBackend+fromSource, fmt.Sprintf("-backend-config=bucket=%s", tfexec.TestS3Bucket))
+
+	toBackend := tfexec.GetTestAccBackendS3Config(t.Name() + "/toDir")
+	toSource := `
+resource "null_resource" "qux" {}
+`
+	toWorkspace := "default"
+	toTf := tfexec.SetupTestAccWithApply(t, toWorkspace, toBackend+toSource)
+
+	// update terraform resource files for migration
+	fromUpdatedSource := `
+resource "null_resource" "baz" {}
+`
+	tfexec.UpdateTestAccSource(t, fromTf, fromBackend+fromUpdatedSource)
+
+	toUpdatedSource := `
+resource "null_resource" "foo" {}
+resource "null_resource" "bar2" {}
+resource "null_resource" "qux" {}
+`
+	tfexec.UpdateTestAccSource(t, toTf, toBackend+toUpdatedSource)
+
+	// perform state migration
+	actions := []MultiStateAction{
+		NewMultiStateMvAction("null_resource.foo_bar", "null_resource.foo"),
+		NewMultiStateMvAction("null_resource.bar", "null_resource.bar2"),
+	}
+	o := &MigratorOption{}
+	force := false
+	m := NewMultiStateMigrator(fromTf.Dir(), toTf.Dir(), fromWorkspace, toWorkspace, actions, o, force, false, false)
+
+	err := m.Plan(ctx)
+	if err == nil {
+		t.Fatalf("expected migrator plan error")
+	}
+
+	expected := "Invalid source address"
+	if !strings.Contains(err.Error(), expected) {
+		t.Fatalf("expected migrator plan error to contain %s, got: %s", expected, err.Error())
+	}
+
+	expected = "Error: \"bucket\": required field is not set"
+	if !strings.Contains(err.Error(), expected) {
+		t.Fatalf("expected migrator plan error to contain %s, got: %s", expected, err.Error())
+	}
+}
